@@ -122,15 +122,16 @@ def main():
                 return "InforION Login is working"
    
     elif typ == 'E':
-        if not program:
-            print('\033[91m' + "Please pass program (API endpoint) name with param -p or --program CRS610MI" + '\033[0m')
-        if not outputfile:
-            print('\033[91m' + "Please pass output file name with param -o or --outputfile CRS610MI" + '\033[0m')
+
+        if not 'program' in locals() or not program:
+            print('\033[91m' + "Error: Program name is missing" + '\033[0m')
+        if not 'outputfile' in locals() or not outputfile:
+            print('\033[91m' + "Error: Output filename is missing" + '\033[0m')
  
         if(program and outputfile):
             generate_api_template_file(program, outputfile)
 
-    else:
+    elif typ == 'T':
         inputdata = pd.read_excel(inputfile)
         return tranform_data(mappingfile,mainsheet,inputdata,outputfile)
     
