@@ -10,9 +10,7 @@ def checkfiletype(filepath):
     # Split the extension from the path and normalise it to lowercase.
     ext = os.path.splitext(filepath)[-1].lower()
     print (ext)
-    # Now we can simply use == to check for equality, no need for wildcards.
 
-    
     if ext == ".csv":
         print ("file is csv")
     elif ext == ".xlsx" or ext == ".xls":
@@ -29,4 +27,16 @@ def loadfile(ext,file):
         df = pd.read_csv(file)
     elif ext == ".xlsx" or ext == ".xls":
         df = pd.read_excel(file)
-    return df
\ No newline at end of file
+    return df
+
+def savetodisk(file,df):
+
+    ext = checkfiletype(file)
+
+    if ext == ".csv":
+        df.to_csv(file)
+    else:
+
+        writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
+        df.to_excel(writer, sheet_name='Log Output',index=False)
+        writer.save()
\ No newline at end of file
