@@ -114,18 +114,16 @@ def execute(url,headers,program,methode,inputfile,outputfile=None,start=0,end=No
 
 
     if outputfile is not None:
+        
+
         print ('Save to file: ' + outputfile)
-        df.to_csv(outputfile)
-        #writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
-        #df.to_excel(writer, sheet_name='Log Output',index=False)
-        #writer.save()
+        filehandling.saveresults(outputfile,df)
+
     
 def executeSnd(url,headers,program,methode,inputfile,outputfile=None,start=0,end=None):
     
-    #df = pd.read_excel("newoutput.xlsx")
-    df = pd.read_csv("newoutput.csv")
-    #, true_values = ['Yes'], false_values = ['No']
-    
+    ext = filehandling.checkfiletype(inputfile)
+    df = filehandling.loadfile(ext,inputfile)
 
 
     tdata = {'program': program,
@@ -187,16 +185,14 @@ def executeSnd(url,headers,program,methode,inputfile,outputfile=None,start=0,end
 
 
     if outputfile is not None:
+        
         print ('Save to file: ' + outputfile)
-        df.to_csv(outputfile)
-        #writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
-        #df.to_excel(writer, sheet_name='Log Output',index=False)
-        #writer.save()
+        filehandling.saveresults(outputfile,df)
 
 def executeAsyncSnd(url,headers,program,methode,inputfile,outputfile=None,start=0,end=None):
 
-    df = pd.read_csv("newoutput.csv", true_values = ['Yes'], false_values = ['No'] )
-    #df = pd.read_excel("newoutput.xlsx", true_values = ['Yes'], false_values = ['No'] )
+    ext = filehandling.checkfiletype(inputfile)
+    df = filehandling.loadfile(ext,inputfile)
         
     data = {'program': program,
             'cono':    409 }
@@ -267,8 +263,4 @@ def executeAsyncSnd(url,headers,program,methode,inputfile,outputfile=None,start=
     
     if outputfile is not None:
         print ('Save to file: ' + outputfile)
-        df.to_csv(outputfile)
-        #writer = pd.ExcelWriter(outputfile, engine='xlsxwriter')
-        #df.to_excel(writer, sheet_name='Log Output',index=False)
-        #writer.save()
-    
\ No newline at end of file
+        filehandling.saveresults(outputfile,df)
\ No newline at end of file
